@@ -2,9 +2,14 @@
 from django.core.validators import RegexValidator
 from django.db.models import CharField
 
+from south.modelsinspector import add_introspection_rules
+
 from .widgets import ColorPickerWidget
 
 
+add_introspection_rules([], ["^django_libs\.models\.ColorField"])
+
+
 class ColorField(CharField):
     """Custom color field to display a color picker."""
     def __init__(self, *args, **kwargs):
